macro_rules! translate {
($target:expr, $value:expr, $map:expr, $(($method:ident, $ty:ty)),* $(,)?) => { ... };
}Expand description
Used to translate serde_json::Value into DataPack<T>.
This macro avoids writing a lot of duplicate code.
macro_rules! translate {
($target:expr, $value:expr, $map:expr, $(($method:ident, $ty:ty)),* $(,)?) => { ... };
}Used to translate serde_json::Value into DataPack<T>.
This macro avoids writing a lot of duplicate code.