pub enum PlotlyInputType {
JSONInput,
SandBoxScript,
}Expand description
NOTE: These configurations are printed as kebab-case names. Please pay attention when using.
Variants
JSONInput
Translates the Json format into an actual plotly object.
NOTE: In the PlotlyOutputType = PlotlySvg state, this method may cause some performance loss due to multiple packaging.
SandBoxScript
NOTE: This entry is deprecated because the use of rquickjs was abandoned.
Execute the script locally in a sandbox, either for preprocessing or to complete the compilation directly.
Once processed, follow the target output type.