PreprocessorConfig

Struct PreprocessorConfig 

pub struct PreprocessorConfig {
    pub output_type: PlotlyOutputType,
    pub input_type: PlotlyInputType,
    pub offline_js_sources: bool,
}
NOTE: These configurations are printed as kebab-case names. Please pay attention when using.

Fields

output_type: PlotlyOutputType

About the output form of the chart. This output format may affect the presentation of the chart.

In addition, in most cases, the different output forms can significantly affect the time at which the book is compiled.

Other: The inner is an enumeration.

input_type: PlotlyInputType

About the input form of the chart.

Charts are usually in the form of code in a markdown document. At the time of input, we allow the code to be presented in different forms.

The two forms we consider for adoption are: a general script and a configuration file organized in a specific form. In theory, you can read and operate files directly from the current path by turning on some of the functions that come with MDBook.

offline_js_sources: bool

About the script source control. If this is false(default), a JS script source from CDN will be injected; otherwise, an HTML script tag containing an embedded JS source will be added for offline use.