handle_json_input

Function handle_json_input 

pub fn handle_json_input(raw_code: String) -> Result<Plot>
Plot does not implement Deserialize, so this routine is only an unofficial best-effort translation.

Do not be surprised if the output of Plot::serialize cannot be round-tripped through this function.

In addition, fields that cannot be translated are silently dropped.